/*  Copyright (c) 2009 Mark Trompell <mark@foresightlinux.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __INDICATOR_H__
#define __INDICATOR_H__

G_BEGIN_DECLS
#ifndef INDICATOR_OBJECT_SIGNAL_ENTRY_SCROLLED
#define INDICATOR_OBJECT_SIGNAL_ENTRY_SCROLLED "scroll-entry"
#endif
/* plugin structure */
typedef struct
{
    XfcePanelPlugin *plugin;

    /* panel widgets */ 
    GtkWidget       *item;
    GtkWidget       *buttonbox;
    GtkWidget       *ebox;

    /* indicator settings */
    gchar          **excluded_modules;
}
IndicatorPlugin;

void
indicator_save (XfcePanelPlugin *plugin,
             IndicatorPlugin    *indicator);

G_END_DECLS

#endif /* !__INDICATOR_H__ */
